Interface: LayoutItem | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: LayoutItem

## # Hierarchy

- `LayoutItem`

  ↳ `Scale`

  ↳ `LegendElement`

## # Properties

### # bottom

• bottom: `number`

Bottom edge of the item. Set by layout system and cannot be used in update

#### # Defined in

layout.d.ts:41
(opens new window)

### # fullSize

• fullSize: `boolean`

if true, and the item is horizontal, then push vertical boxes down

#### # Defined in

layout.d.ts:17
(opens new window)

### # height

• height: `number`

Height of item. Must be valid after update()

#### # Defined in

layout.d.ts:25
(opens new window)

### # left

• left: `number`

Left edge of the item. Set by layout system and cannot be used in update

#### # Defined in

layout.d.ts:29
(opens new window)

### # position

• position: `LayoutPosition`

The position of the item in the chart layout. Possible values are

#### # Defined in

layout.d.ts:9
(opens new window)

### # right

• right: `number`

Right edge of the item. Set by layout system and cannot be used in update

#### # Defined in

layout.d.ts:37
(opens new window)

### # top

• top: `number`

Top edge of the item. Set by layout system and cannot be used in update

#### # Defined in

layout.d.ts:33
(opens new window)

### # weight

• weight: `number`

The weight used to sort the item. Higher weights are further away from the chart area

#### # Defined in

layout.d.ts:13
(opens new window)

### # width

• width: `number`

Width of item. Must be valid after update()

#### # Defined in

layout.d.ts:21
(opens new window)

## # Methods

### # beforeLayout

▸ `Optional` beforeLayout(): `void`

Called before the layout process starts

#### # Returns

`void`

#### # Defined in

layout.d.ts:46
(opens new window)

### # draw

▸ draw(`chartArea`): `void`

Draws the element

#### # Parameters

Name | Type
--- | ---
`chartArea` | `ChartArea`

#### # Returns

`void`

#### # Defined in

layout.d.ts:50
(opens new window)

### # getPadding

▸ `Optional` getPadding(): `ChartArea`

Returns an object with padding on the edges

#### # Returns

`ChartArea`

#### # Defined in

layout.d.ts:54
(opens new window)

### # isHorizontal

▸ isHorizontal(): `boolean`

returns true if the layout item is horizontal (ie. top or bottom)

#### # Returns

`boolean`

#### # Defined in

layout.d.ts:58
(opens new window)

### # update

▸ update(`width`, `height`, `margins?`): `void`

Takes two parameters: width and height.

#### # Parameters

Name | Type
--- | ---
`width` | `number`
`height` | `number`
`margins?` | `ChartArea`

#### # Returns

`void`

#### # Defined in

layout.d.ts:64
(opens new window)